@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from __future__ import absolute_import, division, print_function
 """
 An iterator over multiple lists or other collections.
 Stops at the end of the shortest list.
@@ -8,6 +9,8 @@ From Daniel Dittmar in a discussion "Why I think range is a wart"
 History:
 2005-06-08 ROwen    Changed MultiListIter to a new-style class.
 """
+__all__ = ["MultiListIter"]
+
 class MultiListIter(object):
     def __init__(self, *lists):
         self.iters = map(iter, lists)
@@ -16,15 +19,15 @@ class MultiListIter(object):
         return self
     
     def next(self):
-        return [elem.next() for elem in self.iters]
+        return [next(elem) for elem in self.iters]
 
 
 if __name__ == "__main__":
-    print "MultiListIter example"
+    print("MultiListIter example")
     a = range(5)
     b = [x**2 for x in a]
-    print "a = %r" % a
-    print "b = %r" % b
-    print "for res in MultiListIter(a, b):"
+    print(("a = %r" % a))
+    print(("b = %r" % b))
+    print("for res in MultiListIter(a, b):")
     for res in MultiListIter(a, b):
-        print "\t%r" % (res,)
\ No newline at end of file
+        print(("\t%r" % (res,)))
